checkCameraPermission method
Checks whether the camera permission is granted for SeeSo.
This function asynchronously checks whether the camera permission is granted for the SeeSo SDK. It returns a Future that completes with a boolean value:
trueif the camera permission is granted.falseif the camera permission is not granted.
Implementation
Future<bool> checkCameraPermission() async {
return await Permission.camera.status.isGranted;
}